pub enum SourceValue {
String(String),
StringArray(Vec<String>),
}Expand description
mimetype output (e.g. text/plain), represented as either an array of strings or a string.
Contents of the cell, represented as an array of lines.
The stream’s text output, represented as an array of strings.
Variants