pub struct CodeCell {
pub execution_count: Option<i64>,
pub id: Option<String>,
pub metadata: CellMetadata,
pub outputs: Vec<Value>,
pub source: SourceValue,
}Expand description
Notebook code cell.
Fields
execution_count: Option<i64>The code cell’s prompt number. Will be null if the cell has not been run.
id: Option<String>Technically, id isn’t required (it’s not even present) in schema v4.0 through v4.4, but it’s required in v4.5. Main issue is that pycharm creates notebooks without an id https://youtrack.jetbrains.com/issue/PY-59438/Jupyter-notebooks-created-with-PyCharm-are-missing-the-id-field-in-cells-in-the-.ipynb-json
metadata: CellMetadataCell-level metadata.
outputs: Vec<Value>Execution, display, or stream outputs.
source: SourceValueTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CodeCell
impl<'de> Deserialize<'de> for CodeCell
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for CodeCell