pub struct Kernelspec {
pub language: Option<String>,
pub extra: HashMap<String, Value>,
}Expand description
Kernel information.
Fields
language: Option<String>The language name. This isn’t mentioned in the spec but is populated by various tools and
can be used as a fallback if language_info is missing.
This is also used by VS Code to determine the preferred language of the notebook: https://github.com/microsoft/vscode/blob/1c31e758985efe11bc0453a45ea0bb6887e670a4/extensions/ipynb/src/deserializers.ts#L20-L22.
extra: HashMap<String, Value>For additional properties that isn’t required by Ruff.