pub struct LanguageInfo {
pub codemirror_mode: Option<Value>,
pub file_extension: Option<String>,
pub mimetype: Option<String>,
pub name: String,
pub pygments_lexer: Option<String>,
pub extra: BTreeMap<String, Value>,
}Expand description
Language information.
Fields
codemirror_mode: Option<Value>The codemirror mode to use for code in this language.
file_extension: Option<String>The file extension for files in this language.
mimetype: Option<String>The mimetype corresponding to files in this language.
name: StringThe programming language which this kernel runs.
pygments_lexer: Option<String>The pygments lexer to use for code in this language.
extra: BTreeMap<String, Value>For additional properties.