NotebookIndex

Struct NotebookIndex 

pub struct NotebookIndex { /* private fields */ }
Jupyter Notebook indexing table

When we lint a jupyter notebook, we have to translate the row/column based on ruff_text_size::TextSize to jupyter notebook cell/row/column.

Implementations

Source

impl NotebookIndex

pub fn cell(&self, row: OneIndexed) -> Option<OneIndexed>

Returns the (raw) cell number (1-based) for the given row (1-based).

pub fn cell_row(&self, row: OneIndexed) -> Option<OneIndexed>

Returns the row number (1-based) in the cell (1-based) for the given row (1-based).

pub fn iter(&self) -> impl Iterator<Item = CellStart> + '_

Returns an iterator over the starting rows of each cell (1-based).

This yields one entry per Python cell (skipping over Markdown cell).

pub fn translate_line_column(&self, source_location: &LineColumn) -> LineColumn

Translates the given LineColumn based on the indexing table.

This will translate the row/column in the concatenated source code to the row/column in the Jupyter Notebook cell.

pub fn translate_source_location( &self, source_location: &SourceLocation, ) -> SourceLocation

Translates the given SourceLocation based on the indexing table.

This will translate the line/character in the concatenated source code to the line/character in the Jupyter Notebook cell.