pub struct RawNotebook {
pub cells: Vec<Cell>,
pub metadata: RawNotebookMetadata,
pub nbformat: i64,
pub nbformat_minor: i64,
}Expand description
The root of the JSON of a Jupyter Notebook
Generated by https://app.quicktype.io/ from https://github.com/jupyter/nbformat/blob/16b53251aabf472ad9406ddb1f78b0421c014eeb/nbformat/v4/nbformat.v4.schema.json Jupyter Notebook v4.5 JSON schema.
Fields
cells: Vec<Cell>Array of cells of the current notebook.
metadata: RawNotebookMetadataNotebook root-level metadata.
nbformat: i64Notebook format (major number). Incremented between backwards incompatible changes to the notebook format.
nbformat_minor: i64Notebook format (minor number). Incremented for backward compatible changes to the notebook format.