Notebook

Struct Notebook 

pub struct Notebook { /* private fields */ }

Implementations

Source

impl Notebook

pub fn from_path(path: &Path) -> Result<Self, NotebookError>

Read the Jupyter Notebook from the given Path.

pub fn from_source_code(source_code: &str) -> Result<Self, NotebookError>

Read the Jupyter Notebook from its JSON string.

pub fn from_raw_notebook( raw_notebook: RawNotebook, trailing_newline: bool, ) -> Result<Self, NotebookError>

pub fn empty() -> Self

Creates an empty notebook with a single code cell.

pub fn source_code(&self) -> &str

Return the notebook content.

This is the concatenation of all Python code cells.

pub fn index(&self) -> &NotebookIndex

Return the Jupyter notebook index.

The index is built only once when required. This is only used to report diagnostics, so by that time all of the fixes must have been applied if --fix was passed.

pub fn into_index(self) -> NotebookIndex

Return the Jupyter notebook index, consuming the notebook.

The index is built only once when required. This is only used to report diagnostics, so by that time all of the fixes must have been applied if --fix was passed.

pub fn cell_offsets(&self) -> &CellOffsets

Return the CellOffsets for the concatenated source code corresponding the Jupyter notebook.

pub fn cell_offset(&self, cell: OneIndexed) -> Option<TextSize>

Returns the start offset of the cell at index cell in the concatenated text document.

pub fn cell_range(&self, cell: OneIndexed) -> Option<TextRange>

Returns the text range in the concatenated document of the cell with index cell.

pub fn trailing_newline(&self) -> bool

Return true if the notebook has a trailing newline, false otherwise.

pub fn update(&mut self, source_map: &SourceMap, transformed: String)

Update the notebook with the given sourcemap and transformed content.

pub fn cells(&self) -> &[Cell]

Return a slice of Cell in the Jupyter notebook.

pub fn is_python_notebook(&self) -> bool

Check if it’s a Python notebook.

This is determined by checking the language_info or kernelspec in the notebook metadata. If neither is present, it’s assumed to be a Python notebook.

pub fn write(&self, writer: &mut dyn Write) -> Result<(), NotebookError>

Write the notebook back to the given Write implementer.